/* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
 * $Id: sg_BeagleBone.hpp 1847 2016-05-19 05:28:47Z stephane $
 */

#pragma once

// Central include file for SeeedGrove++ is "sg++.hpp".

#include "sg_LED_patterns.hpp"
#include "sg_BeagleBone_Detect.hpp"
#include "sg_BeagleBone_LED.hpp"
#include "sg_BeagleBone_LEDControl.hpp"
#include "sg_BeagleBone_USB.hpp"
#include "sg_BeagleBone_Watchdog.hpp"
